# Changelog

## 1.0.0 (2025-11-12)

Full Changelog: [v0.0.1...v1.0.0](https://github.com/itellicoAI/server-sdk-python/compare/v0.0.1...v1.0.0)

### Features

* **api:** api update ([2f39067](https://github.com/itellicoAI/server-sdk-python/commit/2f39067570924cd5cc4ee08bac38396cba485a8e))
* **api:** api update ([8d9c52a](https://github.com/itellicoAI/server-sdk-python/commit/8d9c52a8277d4244bbf81af3b3e3f2685b3bf52c))
* **api:** manual updates ([1480229](https://github.com/itellicoAI/server-sdk-python/commit/1480229c9bd891fd2b991bed6dfbb253261fc0f2))
* **api:** manual updates ([bc82f6b](https://github.com/itellicoAI/server-sdk-python/commit/bc82f6b1935f2bf1d00e510ea923811fca68be4a))
* **api:** manual updates ([c886ac2](https://github.com/itellicoAI/server-sdk-python/commit/c886ac2382051190eba0d16378f1d6ed5965d138))
* improve future compat with pydantic v3 ([96a36c0](https://github.com/itellicoAI/server-sdk-python/commit/96a36c034613ec03811ee5a48852036553d77687))
* **types:** replace List[str] with SequenceNotStr in params ([34dc3f2](https://github.com/itellicoAI/server-sdk-python/commit/34dc3f29f36ba0f1e86129b2a2ed9ccd026a9114))


### Bug Fixes

* avoid newer type syntax ([54d4ee3](https://github.com/itellicoAI/server-sdk-python/commit/54d4ee3e822ab7bdb11853a0b3b388edcc840478))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([994578b](https://github.com/itellicoAI/server-sdk-python/commit/994578bc1886c6333e41122797da215323240394))


### Chores

* do not install brew dependencies in ./scripts/bootstrap by default ([5496ab6](https://github.com/itellicoAI/server-sdk-python/commit/5496ab64151d19bcc3b1a55abfd7d849cf698ae8))
* **internal:** add Sequence related utils ([5b9a71b](https://github.com/itellicoAI/server-sdk-python/commit/5b9a71b85bc45f652f30cb8fb6ff09f3be478269))
* **internal:** change ci workflow machines ([7351c6a](https://github.com/itellicoAI/server-sdk-python/commit/7351c6a8c81ad05495a7c0a753f78643d498ea92))
* **internal:** move mypy configurations to `pyproject.toml` file ([09823d4](https://github.com/itellicoAI/server-sdk-python/commit/09823d4b76ad53d4c0ff316740042399de016f86))
* **internal:** update pydantic dependency ([d97046a](https://github.com/itellicoAI/server-sdk-python/commit/d97046ab7da6de023ccb3f12a282effcb8ff1511))
* **internal:** update pyright exclude list ([445b31f](https://github.com/itellicoAI/server-sdk-python/commit/445b31f938a0f856d6578dc0331be64e7ff0c47a))
* **tests:** simplify `get_platform` test ([4d69259](https://github.com/itellicoAI/server-sdk-python/commit/4d69259f066cc841c7799ee97c59d4c15e4be2a5))
* **types:** change optional parameter type from NotGiven to Omit ([ede1b9e](https://github.com/itellicoAI/server-sdk-python/commit/ede1b9e5687a7cb36a41e552120b7264cd7ec11e))
* update SDK settings ([5ce33b1](https://github.com/itellicoAI/server-sdk-python/commit/5ce33b1e8ee50d8ce61b0127dea9c08b323a7888))
* update SDK settings ([3b38ec5](https://github.com/itellicoAI/server-sdk-python/commit/3b38ec5cf871814fe2b9296fa9aadfb831ba8060))
